@@ -264,7 +264,9 @@ def _clean_quantity(element: object) -> Optional[float]:
     """
     Given a quantity, clean and convert it into float numeric format. If element is NaN, or inf, then returns None.
     """
-    element = float(re.sub("[^0-9.,]", "", str(element)).replace(",", "."))
+    no_symbols = re.sub("[^0-9.,]", "", str(element)).replace(",", ".")
+    no_symbols = '0' if no_symbols == '' else no_symbols
+    element = float(no_symbols)
     return _clean_float(element)
 
 
@@ -330,7 +332,7 @@ def _remove_columns(data: pd.DataFrame, identifiers: Dict[str, object], target:
     to_drop = [*[x for x in identifiers.keys() if x != target],
                *[x for x in data.columns if x in dtype_dict and dtype_dict[x] == dtype.invalid]]
 
-    exceptions = ["__mdb_make_predictions"]
+    exceptions = ["__mdb_forecast_offset"]
     if timeseries_settings.group_by is not None:
         exceptions += timeseries_settings.group_by
 
