@@ -7,7 +7,7 @@ from lightwood.helpers.log import log
 from lightwood.helpers.numeric import is_nan_numeric
 from lightwood.mixer.base import BaseMixer
 from lightwood.ensemble.base import BaseEnsemble
-from lightwood.api.types import PredictionArguments
+from lightwood.api.types import PredictionArguments, SubmodelData
 from lightwood.data.encoded_ds import EncodedDs
 from lightwood.helpers.general import evaluate_accuracy
 
@@ -35,6 +35,11 @@ class BestOf(BaseEnsemble):
 
             avg_score = np.mean(list(score_dict.values()))
             log.info(f'Mixer: {type(mixer).__name__} got accuracy: {avg_score}')
+            self.submodel_data.append(SubmodelData(
+                name=type(mixer).__name__,
+                accuracy=avg_score,
+                is_best=False
+            ))
 
             if is_nan_numeric(avg_score):
                 avg_score = -pow(2, 63)
@@ -45,6 +50,7 @@ class BestOf(BaseEnsemble):
         self.indexes_by_accuracy = list(reversed(np.array(score_list).argsort()))
         self.supports_proba = self.mixers[self.indexes_by_accuracy[0]].supports_proba
         log.info(f'Picked best mixer: {type(self.mixers[self.indexes_by_accuracy[0]]).__name__}')
+        self.submodel_data[self.indexes_by_accuracy[0]].is_best = True
 
     def __call__(self, ds: EncodedDs, args: PredictionArguments) -> pd.DataFrame:
         if args.all_mixers:
