@@ -4,6 +4,7 @@ from lightwood.mixer.neural import Neural
 from lightwood.mixer.lightgbm import LightGBM
 from lightwood.mixer.lightgbm_array import LightGBMArray
 from lightwood.mixer.sktime import SkTime
+from lightwood.mixer.prophet import ProphetMixer
 from lightwood.mixer.regression import Regression
 
 try:
@@ -11,4 +12,5 @@ try:
 except Exception:
     QClassic = None
 
-__all__ = ['BaseMixer', 'Neural', 'LightGBM', 'LightGBMArray', 'Unit', 'Regression', 'SkTime', 'QClassic']
+__all__ = ['BaseMixer', 'Neural', 'LightGBM', 'LightGBMArray', 'Unit', 'Regression',
+           'SkTime', 'QClassic', 'ProphetMixer']
